/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.mirror.model;

import com.google.api.client.json.GenericJson;

/**
 * A person or group that can be used as a creator or a contact.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Mirror API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Contact extends GenericJson {

  /**
   * A list of voice menu commands that a contact can handle.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Command> acceptCommands;

  static {
    // hack to force ProGuard to consider Command used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Command.class);
  }

  /**
   * A list of MIME types that a contact supports. The contact will be shown to the user if any of
   * its acceptTypes matches any of the types of the attachments on the item. If no acceptTypes are
   * given, the contact will be shown for all items.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> acceptTypes;

  /**
   * The name to display for this contact.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String displayName;

  /**
   * An ID for this contact. This is generated by the application and is treated as an opaque token.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * Set of image URLs to display for a contact. Most contacts will have a single image, but a
   * "group" contact may include up to 8 image URLs and they will be resized and cropped into a
   * mosaic on the client.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> imageUrls;

  /**
   * The type of resource. This is always mirror#contact.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Primary phone number for the contact. This can be a fully-qualified number, with country
   * calling code and area code, or a local number.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String phoneNumber;

  /**
   * Priority for the contact to determine ordering in a list of contacts. Contacts with higher
   * priorities will be shown before ones with lower priorities.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Long priority;

  /**
   * The ID of the application that created this contact. This is populated by the API
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String source;

  /**
   * Name of this contact as it should be pronounced. If this contact's name must be spoken as part
   * of a voice disambiguation menu, this name is used as the expected pronunciation. This is useful
   * for contact names with unpronounceable characters or whose display spelling is otherwise not
   * phonetic.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String speakableName;

  /**
   * The type for this contact. This is used for sorting in UIs. Allowed values are: - INDIVIDUAL -
   * Represents a single person. This is the default.  - GROUP - Represents more than a single
   * person.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String type;

  /**
   * A list of voice menu commands that a contact can handle.
   * The value returned may be {@code null}.
   */
  public java.util.List<Command> getAcceptCommands() {
    return acceptCommands;
  }

  /**
   * A list of voice menu commands that a contact can handle.
   * The value set may be {@code null}.
   */
  public Contact setAcceptCommands(java.util.List<Command> acceptCommands) {
    this.acceptCommands = acceptCommands;
    return this;
  }

  /**
   * A list of MIME types that a contact supports. The contact will be shown to the user if any of
   * its acceptTypes matches any of the types of the attachments on the item. If no acceptTypes are
   * given, the contact will be shown for all items.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getAcceptTypes() {
    return acceptTypes;
  }

  /**
   * A list of MIME types that a contact supports. The contact will be shown to the user if any of
   * its acceptTypes matches any of the types of the attachments on the item. If no acceptTypes are
   * given, the contact will be shown for all items.
   * The value set may be {@code null}.
   */
  public Contact setAcceptTypes(java.util.List<String> acceptTypes) {
    this.acceptTypes = acceptTypes;
    return this;
  }

  /**
   * The name to display for this contact.
   * The value returned may be {@code null}.
   */
  public String getDisplayName() {
    return displayName;
  }

  /**
   * The name to display for this contact.
   * The value set may be {@code null}.
   */
  public Contact setDisplayName(String displayName) {
    this.displayName = displayName;
    return this;
  }

  /**
   * An ID for this contact. This is generated by the application and is treated as an opaque token.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * An ID for this contact. This is generated by the application and is treated as an opaque token.
   * The value set may be {@code null}.
   */
  public Contact setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * Set of image URLs to display for a contact. Most contacts will have a single image, but a
   * "group" contact may include up to 8 image URLs and they will be resized and cropped into a
   * mosaic on the client.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getImageUrls() {
    return imageUrls;
  }

  /**
   * Set of image URLs to display for a contact. Most contacts will have a single image, but a
   * "group" contact may include up to 8 image URLs and they will be resized and cropped into a
   * mosaic on the client.
   * The value set may be {@code null}.
   */
  public Contact setImageUrls(java.util.List<String> imageUrls) {
    this.imageUrls = imageUrls;
    return this;
  }

  /**
   * The type of resource. This is always mirror#contact.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The type of resource. This is always mirror#contact.
   * The value set may be {@code null}.
   */
  public Contact setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Primary phone number for the contact. This can be a fully-qualified number, with country
   * calling code and area code, or a local number.
   * The value returned may be {@code null}.
   */
  public String getPhoneNumber() {
    return phoneNumber;
  }

  /**
   * Primary phone number for the contact. This can be a fully-qualified number, with country
   * calling code and area code, or a local number.
   * The value set may be {@code null}.
   */
  public Contact setPhoneNumber(String phoneNumber) {
    this.phoneNumber = phoneNumber;
    return this;
  }

  /**
   * Priority for the contact to determine ordering in a list of contacts. Contacts with higher
   * priorities will be shown before ones with lower priorities.
   * The value returned may be {@code null}.
   */
  public Long getPriority() {
    return priority;
  }

  /**
   * Priority for the contact to determine ordering in a list of contacts. Contacts with higher
   * priorities will be shown before ones with lower priorities.
   * The value set may be {@code null}.
   */
  public Contact setPriority(Long priority) {
    this.priority = priority;
    return this;
  }

  /**
   * The ID of the application that created this contact. This is populated by the API
   * The value returned may be {@code null}.
   */
  public String getSource() {
    return source;
  }

  /**
   * The ID of the application that created this contact. This is populated by the API
   * The value set may be {@code null}.
   */
  public Contact setSource(String source) {
    this.source = source;
    return this;
  }

  /**
   * Name of this contact as it should be pronounced. If this contact's name must be spoken as part
   * of a voice disambiguation menu, this name is used as the expected pronunciation. This is useful
   * for contact names with unpronounceable characters or whose display spelling is otherwise not
   * phonetic.
   * The value returned may be {@code null}.
   */
  public String getSpeakableName() {
    return speakableName;
  }

  /**
   * Name of this contact as it should be pronounced. If this contact's name must be spoken as part
   * of a voice disambiguation menu, this name is used as the expected pronunciation. This is useful
   * for contact names with unpronounceable characters or whose display spelling is otherwise not
   * phonetic.
   * The value set may be {@code null}.
   */
  public Contact setSpeakableName(String speakableName) {
    this.speakableName = speakableName;
    return this;
  }

  /**
   * The type for this contact. This is used for sorting in UIs. Allowed values are: - INDIVIDUAL -
   * Represents a single person. This is the default.  - GROUP - Represents more than a single
   * person.
   * The value returned may be {@code null}.
   */
  public String getType() {
    return type;
  }

  /**
   * The type for this contact. This is used for sorting in UIs. Allowed values are: - INDIVIDUAL -
   * Represents a single person. This is the default.  - GROUP - Represents more than a single
   * person.
   * The value set may be {@code null}.
   */
  public Contact setType(String type) {
    this.type = type;
    return this;
  }

}
